==> huaweicloudsdkprojectman-3.0.31rc0-py3-none-any.whl: huaweicloudsdkprojectman/v4/model/issue_request_v4.py <==
# coding: utf-8

import pprint
import re

import six





class IssueRequestV4:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'actual_work_hours': 'int',
        'assigned_id': 'int',
        'begin_time': 'str',
        'description': 'str',
        'developer_id': 'int',
        'domain_id': 'int',
        'done_ratio': 'int',
        'end_time': 'str',
        'expected_work_hours': 'float',
        'iteration_id': 'int',
        'module_id': 'int',
        'name': 'str',
        'parent_issue_id': 'int',
        'priority_id': 'int',
        'severity_id': 'int',
        'status_id': 'int',
        'tracker_id': 'int'
    }

    attribute_map = {
        'actual_work_hours': 'actual_work_hours',
        'assigned_id': 'assigned_id',
        'begin_time': 'begin_time',
        'description': 'description',
        'developer_id': 'developer_id',
        'domain_id': 'domain_id',
        'done_ratio': 'done_ratio',
        'end_time': 'end_time',
        'expected_work_hours': 'expected_work_hours',
        'iteration_id': 'iteration_id',
        'module_id': 'module_id',
        'name': 'name',
        'parent_issue_id': 'parent_issue_id',
        'priority_id': 'priority_id',
        'severity_id': 'severity_id',
        'status_id': 'status_id',
        'tracker_id': 'tracker_id'
    }

    def __init__(self, actual_work_hours=None, assigned_id=None, begin_time=None, description=None, developer_id=None, domain_id=None, done_ratio=None, end_time=None, expected_work_hours=None, iteration_id=None, module_id=None, name=None, parent_issue_id=None, priority_id=None, severity_id=None, status_id=None, tracker_id=None):
        """IssueRequestV4 - a model defined in huaweicloud sdk"""
        
        

        self._actual_work_hours = None
        self._assigned_id = None
        self._begin_time = None
        self._description = None
        self._developer_id = None
        self._domain_id = None
        self._done_ratio = None
        self._end_time = None
        self._expected_work_hours = None
        self._iteration_id = None
        self._module_id = None
        self._name = None
        self._parent_issue_id = None
        self._priority_id = None
        self._severity_id = None
        self._status_id = None
        self._tracker_id = None
        self.discriminator = None

        if actual_work_hours is not None:
            self.actual_work_hours = actual_work_hours
        if assigned_id is not None:
            self.assigned_id = assigned_id
        if begin_time is not None:
            self.begin_time = begin_time
        if description is not None:
            self.description = description
        if developer_id is not None:
            self.developer_id = developer_id
        if domain_id is not None:
            self.domain_id = domain_id
        if done_ratio is not None:
            self.done_ratio = done_ratio
        if end_time is not None:
            self.end_time = end_time
        if expected_work_hours is not None:
            self.expected_work_hours = expected_work_hours
        if iteration_id is not None:
            self.iteration_id = iteration_id
        if module_id is not None:
            self.module_id = module_id
        if name is not None:
            self.name = name
        if parent_issue_id is not None:
            self.parent_issue_id = parent_issue_id
        if priority_id is not None:
            self.priority_id = priority_id
        if severity_id is not None:
            self.severity_id = severity_id
        if status_id is not None:
            self.status_id = status_id
        if tracker_id is not None:
            self.tracker_id = tracker_id

    @property
    def actual_work_hours(self):
        """Gets the actual_work_hours of this IssueRequestV4.

        实际工时

        :return: The actual_work_hours of this IssueRequestV4.
        :rtype: int
        """
        return self._actual_work_hours

    @actual_work_hours.setter
    def actual_work_hours(self, actual_work_hours):
        """Sets the actual_work_hours of this IssueRequestV4.

        实际工时

        :param actual_work_hours: The actual_work_hours of this IssueRequestV4.
        :type: int
        """
        self._actual_work_hours = actual_work_hours

    @property
    def assigned_id(self):
        """Gets the assigned_id of this IssueRequestV4.

        处理人id,对应用户信息的数字id

        :return: The assigned_id of this IssueRequestV4.
        :rtype: int
        """
        return self._assigned_id

    @assigned_id.setter
    def assigned_id(self, assigned_id):
        """Sets the assigned_id of this IssueRequestV4.

        处理人id,对应用户信息的数字id

        :param assigned_id: The assigned_id of this IssueRequestV4.
        :type: int
        """
        self._assigned_id = assigned_id

    @property
    def begin_time(self):
        """Gets the begin_time of this IssueRequestV4.

        开始时间，年-月-日

        :return: The begin_time of this IssueRequestV4.
        :rtype: str
        """
        return self._begin_time

    @begin_time.setter
    def begin_time(self, begin_time):
        """Sets the begin_time of this IssueRequestV4.

        开始时间，年-月-日

        :param begin_time: The begin_time of this IssueRequestV4.
        :type: str
        """
        self._begin_time = begin_time

    @property
    def description(self):
        """Gets the description of this IssueRequestV4.

        描述信息

        :return: The description of this IssueRequestV4.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this IssueRequestV4.

        描述信息

        :param description: The description of this IssueRequestV4.
        :type: str
        """
        self._description = description

    @property
    def developer_id(self):
        """Gets the developer_id of this IssueRequestV4.

        开发者id,对应用户信息的数字id

        :return: The developer_id of this IssueRequestV4.
        :rtype: int
        """
        return self._developer_id

    @developer_id.setter
    def developer_id(self, developer_id):
        """Sets the developer_id of this IssueRequestV4.

        开发者id,对应用户信息的数字id

        :param developer_id: The developer_id of this IssueRequestV4.
        :type: int
        """
        self._developer_id = developer_id

    @property
    def domain_id(self):
        """Gets the domain_id of this IssueRequestV4.

        领域id

        :return: The domain_id of this IssueRequestV4.
        :rtype: int
        """
        return self._domain_id

    @domain_id.setter
    def domain_id(self, domain_id):
        """Sets the domain_id of this IssueRequestV4.

        领域id

        :param domain_id: The domain_id of this IssueRequestV4.
        :type: int
        """
        self._domain_id = domain_id

    @property
    def done_ratio(self):
        """Gets the done_ratio of this IssueRequestV4.

        工作项进度值

        :return: The done_ratio of this IssueRequestV4.
        :rtype: int
        """
        return self._done_ratio

    @done_ratio.setter
    def done_ratio(self, done_ratio):
        """Sets the done_ratio of this IssueRequestV4.

        工作项进度值

        :param done_ratio: The done_ratio of this IssueRequestV4.
        :type: int
        """
        self._done_ratio = done_ratio

    @property
    def end_time(self):
        """Gets the end_time of this IssueRequestV4.

        结束时间，年-月-日

        :return: The end_time of this IssueRequestV4.
        :rtype: str
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this IssueRequestV4.

        结束时间，年-月-日

        :param end_time: The end_time of this IssueRequestV4.
        :type: str
        """
        self._end_time = end_time

    @property
    def expected_work_hours(self):
        """Gets the expected_work_hours of this IssueRequestV4.

        预计工时

        :return: The expected_work_hours of this IssueRequestV4.
        :rtype: float
        """
        return self._expected_work_hours

    @expected_work_hours.setter
    def expected_work_hours(self, expected_work_hours):
        """Sets the expected_work_hours of this IssueRequestV4.

        预计工时

        :param expected_work_hours: The expected_work_hours of this IssueRequestV4.
        :type: float
        """
        self._expected_work_hours = expected_work_hours

    @property
    def iteration_id(self):
        """Gets the iteration_id of this IssueRequestV4.

        迭代id

        :return: The iteration_id of this IssueRequestV4.
        :rtype: int
        """
        return self._iteration_id

    @iteration_id.setter
    def iteration_id(self, iteration_id):
        """Sets the iteration_id of this IssueRequestV4.

        迭代id

        :param iteration_id: The iteration_id of this IssueRequestV4.
        :type: int
        """
        self._iteration_id = iteration_id

    @property
    def module_id(self):
        """Gets the module_id of this IssueRequestV4.

        模块id

        :return: The module_id of this IssueRequestV4.
        :rtype: int
        """
        return self._module_id

    @module_id.setter
    def module_id(self, module_id):
        """Sets the module_id of this IssueRequestV4.

        模块id

        :param module_id: The module_id of this IssueRequestV4.
        :type: int
        """
        self._module_id = module_id

    @property
    def name(self):
        """Gets the name of this IssueRequestV4.

        标题

        :return: The name of this IssueRequestV4.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this IssueRequestV4.

        标题

        :param name: The name of this IssueRequestV4.
        :type: str
        """
        self._name = name

    @property
    def parent_issue_id(self):
        """Gets the parent_issue_id of this IssueRequestV4.

        父工作项的id

        :return: The parent_issue_id of this IssueRequestV4.
        :rtype: int
        """
        return self._parent_issue_id

    @parent_issue_id.setter
    def parent_issue_id(self, parent_issue_id):
        """Sets the parent_issue_id of this IssueRequestV4.

        父工作项的id

        :param parent_issue_id: The parent_issue_id of this IssueRequestV4.
        :type: int
        """
        self._parent_issue_id = parent_issue_id

    @property
    def priority_id(self):
        """Gets the priority_id of this IssueRequestV4.

        优先级   1 低   2 中   3 高

        :return: The priority_id of this IssueRequestV4.
        :rtype: int
        """
        return self._priority_id

    @priority_id.setter
    def priority_id(self, priority_id):
        """Sets the priority_id of this IssueRequestV4.

        优先级   1 低   2 中   3 高

        :param priority_id: The priority_id of this IssueRequestV4.
        :type: int
        """
        self._priority_id = priority_id

    @property
    def severity_id(self):
        """Gets the severity_id of this IssueRequestV4.

        重要程度   10 关键   11 重要   12 一般   13 提示

        :return: The severity_id of this IssueRequestV4.
        :rtype: int
        """
        return self._severity_id

    @severity_id.setter
    def severity_id(self, severity_id):
        """Sets the severity_id of this IssueRequestV4.

        重要程度   10 关键   11 重要   12 一般   13 提示

        :param severity_id: The severity_id of this IssueRequestV4.
        :type: int
        """
        self._severity_id = severity_id

    @property
    def status_id(self):
        """Gets the status_id of this IssueRequestV4.

        状态   id 开始   1 进行中 2 已解决 3 测试中 4 已关闭 5 已解决 6

        :return: The status_id of this IssueRequestV4.
        :rtype: int
        """
        return self._status_id

    @status_id.setter
    def status_id(self, status_id):
        """Sets the status_id of this IssueRequestV4.

        状态   id 开始   1 进行中 2 已解决 3 测试中 4 已关闭 5 已解决 6

        :param status_id: The status_id of this IssueRequestV4.
        :type: int
        """
        self._status_id = status_id

    @property
    def tracker_id(self):
        """Gets the tracker_id of this IssueRequestV4.

        工作项类型,2任务/task,3缺陷/bug,5epic,6feature,7story

        :return: The tracker_id of this IssueRequestV4.
        :rtype: int
        """
        return self._tracker_id

    @tracker_id.setter
    def tracker_id(self, tracker_id):
        """Sets the tracker_id of this IssueRequestV4.

        工作项类型,2任务/task,3缺陷/bug,5epic,6feature,7story

        :param tracker_id: The tracker_id of this IssueRequestV4.
        :type: int
        """
        self._tracker_id = tracker_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IssueRequestV4):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkprojectman-3.0.41rc0-py3-none-any.whl: huaweicloudsdkprojectman/v4/model/issue_request_v4.py <==
# coding: utf-8

import pprint
import re

import six





class IssueRequestV4:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'actual_work_hours': 'float',
        'assigned_id': 'int',
        'begin_time': 'str',
        'description': 'str',
        'developer_id': 'int',
        'domain_id': 'int',
        'done_ratio': 'int',
        'end_time': 'str',
        'expected_work_hours': 'float',
        'iteration_id': 'int',
        'module_id': 'int',
        'name': 'str',
        'parent_issue_id': 'int',
        'priority_id': 'int',
        'severity_id': 'int',
        'status_id': 'int',
        'tracker_id': 'int'
    }

    attribute_map = {
        'actual_work_hours': 'actual_work_hours',
        'assigned_id': 'assigned_id',
        'begin_time': 'begin_time',
        'description': 'description',
        'developer_id': 'developer_id',
        'domain_id': 'domain_id',
        'done_ratio': 'done_ratio',
        'end_time': 'end_time',
        'expected_work_hours': 'expected_work_hours',
        'iteration_id': 'iteration_id',
        'module_id': 'module_id',
        'name': 'name',
        'parent_issue_id': 'parent_issue_id',
        'priority_id': 'priority_id',
        'severity_id': 'severity_id',
        'status_id': 'status_id',
        'tracker_id': 'tracker_id'
    }

    def __init__(self, actual_work_hours=None, assigned_id=None, begin_time=None, description=None, developer_id=None, domain_id=None, done_ratio=None, end_time=None, expected_work_hours=None, iteration_id=None, module_id=None, name=None, parent_issue_id=None, priority_id=None, severity_id=None, status_id=None, tracker_id=None):
        """IssueRequestV4 - a model defined in huaweicloud sdk"""
        
        

        self._actual_work_hours = None
        self._assigned_id = None
        self._begin_time = None
        self._description = None
        self._developer_id = None
        self._domain_id = None
        self._done_ratio = None
        self._end_time = None
        self._expected_work_hours = None
        self._iteration_id = None
        self._module_id = None
        self._name = None
        self._parent_issue_id = None
        self._priority_id = None
        self._severity_id = None
        self._status_id = None
        self._tracker_id = None
        self.discriminator = None

        if actual_work_hours is not None:
            self.actual_work_hours = actual_work_hours
        if assigned_id is not None:
            self.assigned_id = assigned_id
        if begin_time is not None:
            self.begin_time = begin_time
        if description is not None:
            self.description = description
        if developer_id is not None:
            self.developer_id = developer_id
        if domain_id is not None:
            self.domain_id = domain_id
        if done_ratio is not None:
            self.done_ratio = done_ratio
        if end_time is not None:
            self.end_time = end_time
        if expected_work_hours is not None:
            self.expected_work_hours = expected_work_hours
        if iteration_id is not None:
            self.iteration_id = iteration_id
        if module_id is not None:
            self.module_id = module_id
        if name is not None:
            self.name = name
        if parent_issue_id is not None:
            self.parent_issue_id = parent_issue_id
        if priority_id is not None:
            self.priority_id = priority_id
        if severity_id is not None:
            self.severity_id = severity_id
        if status_id is not None:
            self.status_id = status_id
        if tracker_id is not None:
            self.tracker_id = tracker_id

    @property
    def actual_work_hours(self):
        """Gets the actual_work_hours of this IssueRequestV4.

        实际工时

        :return: The actual_work_hours of this IssueRequestV4.
        :rtype: float
        """
        return self._actual_work_hours

    @actual_work_hours.setter
    def actual_work_hours(self, actual_work_hours):
        """Sets the actual_work_hours of this IssueRequestV4.

        实际工时

        :param actual_work_hours: The actual_work_hours of this IssueRequestV4.
        :type: float
        """
        self._actual_work_hours = actual_work_hours

    @property
    def assigned_id(self):
        """Gets the assigned_id of this IssueRequestV4.

        处理人id,对应用户信息的数字id

        :return: The assigned_id of this IssueRequestV4.
        :rtype: int
        """
        return self._assigned_id

    @assigned_id.setter
    def assigned_id(self, assigned_id):
        """Sets the assigned_id of this IssueRequestV4.

        处理人id,对应用户信息的数字id

        :param assigned_id: The assigned_id of this IssueRequestV4.
        :type: int
        """
        self._assigned_id = assigned_id

    @property
    def begin_time(self):
        """Gets the begin_time of this IssueRequestV4.

        开始时间，年-月-日

        :return: The begin_time of this IssueRequestV4.
        :rtype: str
        """
        return self._begin_time

    @begin_time.setter
    def begin_time(self, begin_time):
        """Sets the begin_time of this IssueRequestV4.

        开始时间，年-月-日

        :param begin_time: The begin_time of this IssueRequestV4.
        :type: str
        """
        self._begin_time = begin_time

    @property
    def description(self):
        """Gets the description of this IssueRequestV4.

        描述信息

        :return: The description of this IssueRequestV4.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this IssueRequestV4.

        描述信息

        :param description: The description of this IssueRequestV4.
        :type: str
        """
        self._description = description

    @property
    def developer_id(self):
        """Gets the developer_id of this IssueRequestV4.

        开发者id,对应用户信息的数字id

        :return: The developer_id of this IssueRequestV4.
        :rtype: int
        """
        return self._developer_id

    @developer_id.setter
    def developer_id(self, developer_id):
        """Sets the developer_id of this IssueRequestV4.

        开发者id,对应用户信息的数字id

        :param developer_id: The developer_id of this IssueRequestV4.
        :type: int
        """
        self._developer_id = developer_id

    @property
    def domain_id(self):
        """Gets the domain_id of this IssueRequestV4.

        领域id

        :return: The domain_id of this IssueRequestV4.
        :rtype: int
        """
        return self._domain_id

    @domain_id.setter
    def domain_id(self, domain_id):
        """Sets the domain_id of this IssueRequestV4.

        领域id

        :param domain_id: The domain_id of this IssueRequestV4.
        :type: int
        """
        self._domain_id = domain_id

    @property
    def done_ratio(self):
        """Gets the done_ratio of this IssueRequestV4.

        工作项进度值

        :return: The done_ratio of this IssueRequestV4.
        :rtype: int
        """
        return self._done_ratio

    @done_ratio.setter
    def done_ratio(self, done_ratio):
        """Sets the done_ratio of this IssueRequestV4.

        工作项进度值

        :param done_ratio: The done_ratio of this IssueRequestV4.
        :type: int
        """
        self._done_ratio = done_ratio

    @property
    def end_time(self):
        """Gets the end_time of this IssueRequestV4.

        结束时间，年-月-日

        :return: The end_time of this IssueRequestV4.
        :rtype: str
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this IssueRequestV4.

        结束时间，年-月-日

        :param end_time: The end_time of this IssueRequestV4.
        :type: str
        """
        self._end_time = end_time

    @property
    def expected_work_hours(self):
        """Gets the expected_work_hours of this IssueRequestV4.

        预计工时

        :return: The expected_work_hours of this IssueRequestV4.
        :rtype: float
        """
        return self._expected_work_hours

    @expected_work_hours.setter
    def expected_work_hours(self, expected_work_hours):
        """Sets the expected_work_hours of this IssueRequestV4.

        预计工时

        :param expected_work_hours: The expected_work_hours of this IssueRequestV4.
        :type: float
        """
        self._expected_work_hours = expected_work_hours

    @property
    def iteration_id(self):
        """Gets the iteration_id of this IssueRequestV4.

        迭代id

        :return: The iteration_id of this IssueRequestV4.
        :rtype: int
        """
        return self._iteration_id

    @iteration_id.setter
    def iteration_id(self, iteration_id):
        """Sets the iteration_id of this IssueRequestV4.

        迭代id

        :param iteration_id: The iteration_id of this IssueRequestV4.
        :type: int
        """
        self._iteration_id = iteration_id

    @property
    def module_id(self):
        """Gets the module_id of this IssueRequestV4.

        模块id

        :return: The module_id of this IssueRequestV4.
        :rtype: int
        """
        return self._module_id

    @module_id.setter
    def module_id(self, module_id):
        """Sets the module_id of this IssueRequestV4.

        模块id

        :param module_id: The module_id of this IssueRequestV4.
        :type: int
        """
        self._module_id = module_id

    @property
    def name(self):
        """Gets the name of this IssueRequestV4.

        标题

        :return: The name of this IssueRequestV4.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this IssueRequestV4.

        标题

        :param name: The name of this IssueRequestV4.
        :type: str
        """
        self._name = name

    @property
    def parent_issue_id(self):
        """Gets the parent_issue_id of this IssueRequestV4.

        父工作项的id

        :return: The parent_issue_id of this IssueRequestV4.
        :rtype: int
        """
        return self._parent_issue_id

    @parent_issue_id.setter
    def parent_issue_id(self, parent_issue_id):
        """Sets the parent_issue_id of this IssueRequestV4.

        父工作项的id

        :param parent_issue_id: The parent_issue_id of this IssueRequestV4.
        :type: int
        """
        self._parent_issue_id = parent_issue_id

    @property
    def priority_id(self):
        """Gets the priority_id of this IssueRequestV4.

        优先级,   1 低,   2 中,   3 高,

        :return: The priority_id of this IssueRequestV4.
        :rtype: int
        """
        return self._priority_id

    @priority_id.setter
    def priority_id(self, priority_id):
        """Sets the priority_id of this IssueRequestV4.

        优先级,   1 低,   2 中,   3 高,

        :param priority_id: The priority_id of this IssueRequestV4.
        :type: int
        """
        self._priority_id = priority_id

    @property
    def severity_id(self):
        """Gets the severity_id of this IssueRequestV4.

        重要程度,   10 关键,   11 重要,   12 一般,   13 提示,

        :return: The severity_id of this IssueRequestV4.
        :rtype: int
        """
        return self._severity_id

    @severity_id.setter
    def severity_id(self, severity_id):
        """Sets the severity_id of this IssueRequestV4.

        重要程度,   10 关键,   11 重要,   12 一般,   13 提示,

        :param severity_id: The severity_id of this IssueRequestV4.
        :type: int
        """
        self._severity_id = severity_id

    @property
    def status_id(self):
        """Gets the status_id of this IssueRequestV4.

        状态   id, 开始   1, 进行中 2, 已解决 3, 测试中 4, 已关闭 5, 已解决 6,

        :return: The status_id of this IssueRequestV4.
        :rtype: int
        """
        return self._status_id

    @status_id.setter
    def status_id(self, status_id):
        """Sets the status_id of this IssueRequestV4.

        状态   id, 开始   1, 进行中 2, 已解决 3, 测试中 4, 已关闭 5, 已解决 6,

        :param status_id: The status_id of this IssueRequestV4.
        :type: int
        """
        self._status_id = status_id

    @property
    def tracker_id(self):
        """Gets the tracker_id of this IssueRequestV4.

        工作项类型,2任务/task,3缺陷/bug,5epic,6feature,7story

        :return: The tracker_id of this IssueRequestV4.
        :rtype: int
        """
        return self._tracker_id

    @tracker_id.setter
    def tracker_id(self, tracker_id):
        """Sets the tracker_id of this IssueRequestV4.

        工作项类型,2任务/task,3缺陷/bug,5epic,6feature,7story

        :param tracker_id: The tracker_id of this IssueRequestV4.
        :type: int
        """
        self._tracker_id = tracker_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IssueRequestV4):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
